==> linuxconf-1.28.src.tar.gz: linuxconf-1.28/installdemo.sh <==
#!/bin/sh
cd /
DEM=/demo_linuxconf
rm -fr $DEM
mkdir $DEM
mkdir $DEM/etc $DEM/etc/ppp $DEM/lib
mkdir $DEM/etc/sysconfig $DEM/etc/sysconfig/network-scripts
echo >$DEM/etc/ppp/ppplogin
echo >$DEM/etc/ppp/ppplogin24
chmod +x $DEM/etc/ppp/ppplogin $DEM/etc/ppp/ppplogin24
echo LINUXCONF.distribution redhat >>$DEM/etc/conf.linuxconf
echo shells.ppp /etc/ppp/ppplogin >>$DEM/etc/conf.linuxconf
echo shells.ppp /etc/ppp/ppplogin24 >>$DEM/etc/conf.linuxconf
echo notice.10-welcome.help 874901022 >>$DEM/etc/conf.linuxconf
echo module.list 1 netadm >>$DEM/etc/conf.linuxconf
echo module.list 1 apache >>$DEM/etc/conf.linuxconf
echo module.list 1 samba >>$DEM/etc/conf.linuxconf
echo module.list 1 dhcpd >>$DEM/etc/conf.linuxconf
echo module.list 1 wuftpd >>$DEM/etc/conf.linuxconf
echo module.list 1 mrtg >>$DEM/etc/conf.linuxconf
echo module.list 1 squid >>$DEM/etc/conf.linuxconf
echo module.list 1 usermenu >>$DEM/etc/conf.linuxconf
echo module.list 1 pppdialin >>$DEM/etc/conf.linuxconf
echo module.list 1 mailconf >>$DEM/etc/conf.linuxconf
echo module.list 1 dnsconf >>$DEM/etc/conf.linuxconf
echo module.list 1 dialout >>$DEM/etc/conf.linuxconf
echo module.list 1 motd >>$DEM/etc/conf.linuxconf
echo module.list 1 rarp >>$DEM/etc/conf.linuxconf

mkdir $DEM/bin
mkdir $DEM/home
mkdir -p $DEM/home/httpd/html/mrtg
mkdir $DEM/proc $DEM/proc/net
cat /proc/net/dev >$DEM/proc/net/dev

mkdir $DEM/tmp
chmod 1777 $DEM/tmp
mkdir -p $DEM/usr/src/linux/arch/i386/boot
echo >$DEM/usr/src/linux/arch/i386/boot/zImage
cat <<-EOF >$DEM/usr/src/linux/Makefile
	echo VERSION = 2
	echo PATCHLEVEL = 0
	echo SUBLEVEL = 22
EOF

cat <<-EOF >$DEM/etc/lilo.conf
	boot = /dev/hda
	delay = 50
	  ramdisk = 0
	  vga = normal
	  root = /dev/hda2
	  read-only
	image = /etc/kernel-2.0.22
	  label = k2022
	  vga = normal
	image = /etc/kernel-2.0.21
	  label = k2021
	  vga = normal
	other = /dev/hda1
	  label = dos
	other = /dev/hda5
	  label = nt
EOF

echo 1.2.3.4	demo.foo.com demo loghost >$DEM/etc/hosts
echo order hosts,bind >$DEM/etc/host.conf
echo >$DEM/etc/networks
cp /etc/services $DEM/etc
cp /etc/protocols $DEM/etc

echo "[public]"		>$DEM/etc/smb.conf
echo "[printers]"	>>$DEM/etc/smb.conf
echo "[homes]"		>>$DEM/etc/smb.conf

echo htmlaccess.from 0.0.0.0 0.0.0.0 >>$DEM/etc/conf.linuxconf
echo htmlaccess.dolog 1 >>$DEM/etc/conf.linuxconf
echo htmlaccess.enable 1 >>$DEM/etc/conf.linuxconf
mkdir -p $DEM/usr/lib
mkdir -p $DEM/usr/lib/linuxconf
mkdir -p $DEM/usr/X11R6/lib
mkdir -p $DEM/var/log
cp -a /usr/lib/linuxconf/. $DEM/usr/lib/linuxconf
cp -a /lib/libnss* $DEM/lib/.
cp -a /usr/lib/libstdc++* $DEM/usr/lib/.
cp -a /usr/lib/libxml* $DEM/usr/lib/.
cp -a /usr/X11R6/lib/*.so* $DEM/usr/X11R6/lib/.
echo root:x:0:0:root:/root:/bin/bash >$DEM/etc/passwd
echo root:ZIy6Ivgw8UdAs:9780:0:99999:7:0:0: >$DEM/etc/shadow
cp -a /etc/group $DEM/etc/group

echo /dev/hda1	none swap	defaults	1 1 >$DEM/etc/fstab
echo /dev/hda2	/    ext2	defaults,usrquota,grpquota	1 1 >>$DEM/etc/fstab

# some executable stubs
for s in /bin/sh /bin/csh /bin/false /bin/bash
do
	echo >$DEM$s
	chmod +x $DEM$s
done
echo /bin/bash >$DEM/etc/shells
echo /bin/sh >>$DEM/etc/shells
echo /bin/csh >>$DEM/etc/shells

echo
echo -n Kill all current linuxconf process " ? (y/n) "
read yes
if [ "$yes" = "y" ] ; then
	killall linuxconf
fi

==> linuxconf-1.31r1.src.tar.gz: linuxconf-1.31r1/installdemo.sh <==
#!/bin/sh
cd /
DEM=/demo_linuxconf
rm -fr $DEM
mkdir $DEM
mkdir $DEM/etc $DEM/etc/ppp $DEM/lib
mkdir $DEM/etc/sysconfig $DEM/etc/sysconfig/network-scripts
echo >$DEM/etc/ppp/ppplogin
echo >$DEM/etc/ppp/ppplogin24
chmod +x $DEM/etc/ppp/ppplogin $DEM/etc/ppp/ppplogin24
echo LINUXCONF.distribution redhat >>$DEM/etc/conf.linuxconf
echo shells.ppp /etc/ppp/ppplogin >>$DEM/etc/conf.linuxconf
echo shells.ppp /etc/ppp/ppplogin24 >>$DEM/etc/conf.linuxconf
echo notice.10-welcome.help 874901022 >>$DEM/etc/conf.linuxconf
echo module.list 1 netadm >>$DEM/etc/conf.linuxconf
echo module.list 1 apache >>$DEM/etc/conf.linuxconf
echo module.list 1 samba >>$DEM/etc/conf.linuxconf
echo module.list 1 dhcpd >>$DEM/etc/conf.linuxconf
echo module.list 1 wuftpd >>$DEM/etc/conf.linuxconf
echo module.list 1 mrtg >>$DEM/etc/conf.linuxconf
echo module.list 1 squid >>$DEM/etc/conf.linuxconf
echo module.list 1 usermenu >>$DEM/etc/conf.linuxconf
echo module.list 1 pppdialin >>$DEM/etc/conf.linuxconf
echo module.list 1 mailconf >>$DEM/etc/conf.linuxconf
echo module.list 1 dnsconf >>$DEM/etc/conf.linuxconf
echo module.list 1 dialout >>$DEM/etc/conf.linuxconf
echo module.list 1 motd >>$DEM/etc/conf.linuxconf
echo module.list 1 rarp >>$DEM/etc/conf.linuxconf

mkdir $DEM/bin
mkdir -p $DEM/usr/bin
cp /bin/true $DEM/usr/bin/smbpasswd
mkdir $DEM/home
mkdir $DEM/etc/samba
mkdir -p $DEM/home/httpd/html/mrtg
mkdir $DEM/proc $DEM/proc/net
cat /proc/net/dev >$DEM/proc/net/dev

mkdir $DEM/tmp
chmod 1777 $DEM/tmp
mkdir -p $DEM/usr/src/linux/arch/i386/boot
echo >$DEM/usr/src/linux/arch/i386/boot/zImage
cat <<-EOF >$DEM/usr/src/linux/Makefile
	echo VERSION = 2
	echo PATCHLEVEL = 0
	echo SUBLEVEL = 22
EOF

cat <<-EOF >$DEM/etc/lilo.conf
	boot = /dev/hda
	delay = 50
	  ramdisk = 0
	  vga = normal
	  root = /dev/hda2
	  read-only
	image = /etc/kernel-2.0.22
	  label = k2022
	  vga = normal
	image = /etc/kernel-2.0.21
	  label = k2021
	  vga = normal
	other = /dev/hda1
	  label = dos
	other = /dev/hda5
	  label = nt
EOF

echo 1.2.3.4	demo.foo.com demo loghost >$DEM/etc/hosts
echo order hosts,bind >$DEM/etc/host.conf
echo >$DEM/etc/networks
cp /etc/services $DEM/etc
cp /etc/protocols $DEM/etc

echo "[public]"		>$DEM/etc/samba/smb.conf
echo "[printers]"	>>$DEM/etc/samba/smb.conf
echo "[homes]"		>>$DEM/etc/samba/smb.conf
touch $DEM/etc/samba/smbpasswd

echo htmlaccess.from 0.0.0.0 0.0.0.0 >>$DEM/etc/conf.linuxconf
echo htmlaccess.dolog 1 >>$DEM/etc/conf.linuxconf
echo htmlaccess.enable 1 >>$DEM/etc/conf.linuxconf
mkdir -p $DEM/usr/lib
mkdir -p $DEM/usr/lib/linuxconf
mkdir -p $DEM/usr/X11R6/lib
mkdir -p $DEM/var/log
cp -a /usr/lib/linuxconf/. $DEM/usr/lib/linuxconf
cp -a /lib/libnss* $DEM/lib/.
cp -a /usr/lib/libstdc++* $DEM/usr/lib/.
cp -a /usr/lib/libxml* $DEM/usr/lib/.
cp -a /usr/X11R6/lib/*.so* $DEM/usr/X11R6/lib/.
echo root:x:0:0:root:/root:/bin/bash >$DEM/etc/passwd
echo root:ZIy6Ivgw8UdAs:9780:0:99999:7:0:0: >$DEM/etc/shadow
cp -a /etc/group $DEM/etc/group

echo /dev/hda1	none swap	defaults	1 1 >$DEM/etc/fstab
echo /dev/hda2	/    ext2	defaults,usrquota,grpquota	1 1 >>$DEM/etc/fstab

# some executable stubs
for s in /bin/sh /bin/csh /bin/false /bin/bash
do
	echo >$DEM$s
	chmod +x $DEM$s
done
echo /bin/bash >$DEM/etc/shells
echo /bin/sh >>$DEM/etc/shells
echo /bin/csh >>$DEM/etc/shells

echo
echo -n Kill all current linuxconf process " ? (y/n) "
read yes
if [ "$yes" = "y" ] ; then
	killall linuxconf
fi
